==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_entities/equipmentstructure_001/EquipmentStructure.java <==

package net.datastream.schemas.mp_entities.equipmentstructure_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTSTRUCTUREID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTRUCTUREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTROLLUP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTON" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentstructureid",
    "costrollup",
    "dependenton",
    "sequencenumber"
})
@XmlRootElement(name = "EquipmentStructure")
public class EquipmentStructure {

    @XmlElement(name = "EQUIPMENTSTRUCTUREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTSTRUCTUREID_Type equipmentstructureid;
    @XmlElement(name = "COSTROLLUP", namespace = "http://schemas.datastream.net/MP_fields")
    protected String costrollup;
    @XmlElement(name = "DEPENDENTON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String dependenton;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long sequencenumber;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété equipmentstructureid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTSTRUCTUREID_Type }
     *     
     */
    public EQUIPMENTSTRUCTUREID_Type getEQUIPMENTSTRUCTUREID() {
        return equipmentstructureid;
    }

    /**
     * Définit la valeur de la propriété equipmentstructureid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTSTRUCTUREID_Type }
     *     
     */
    public void setEQUIPMENTSTRUCTUREID(EQUIPMENTSTRUCTUREID_Type value) {
        this.equipmentstructureid = value;
    }

    /**
     * Obtient la valeur de la propriété costrollup.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTROLLUP() {
        return costrollup;
    }

    /**
     * Définit la valeur de la propriété costrollup.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTROLLUP(String value) {
        this.costrollup = value;
    }

    /**
     * Obtient la valeur de la propriété dependenton.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEPENDENTON() {
        return dependenton;
    }

    /**
     * Définit la valeur de la propriété dependenton.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEPENDENTON(String value) {
        this.dependenton = value;
    }

    /**
     * Obtient la valeur de la propriété sequencenumber.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Définit la valeur de la propriété sequencenumber.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSEQUENCENUMBER(Long value) {
        this.sequencenumber = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_entities/equipmentstructure_001/EquipmentStructure.java <==

package net.datastream.schemas.mp_entities.equipmentstructure_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTSTRUCTUREID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTRUCTUREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTROLLUP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTON" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentstructureid",
    "costrollup",
    "dependenton",
    "sequencenumber"
})
@XmlRootElement(name = "EquipmentStructure")
public class EquipmentStructure {

    @XmlElement(name = "EQUIPMENTSTRUCTUREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTSTRUCTUREID_Type equipmentstructureid;
    @XmlElement(name = "COSTROLLUP", namespace = "http://schemas.datastream.net/MP_fields")
    protected String costrollup;
    @XmlElement(name = "DEPENDENTON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String dependenton;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long sequencenumber;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the equipmentstructureid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTSTRUCTUREID_Type }
     *     
     */
    public EQUIPMENTSTRUCTUREID_Type getEQUIPMENTSTRUCTUREID() {
        return equipmentstructureid;
    }

    /**
     * Sets the value of the equipmentstructureid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTSTRUCTUREID_Type }
     *     
     */
    public void setEQUIPMENTSTRUCTUREID(EQUIPMENTSTRUCTUREID_Type value) {
        this.equipmentstructureid = value;
    }

    /**
     * Gets the value of the costrollup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTROLLUP() {
        return costrollup;
    }

    /**
     * Sets the value of the costrollup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTROLLUP(String value) {
        this.costrollup = value;
    }

    /**
     * Gets the value of the dependenton property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEPENDENTON() {
        return dependenton;
    }

    /**
     * Sets the value of the dependenton property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEPENDENTON(String value) {
        this.dependenton = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSEQUENCENUMBER(Long value) {
        this.sequencenumber = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
